#include <stdlib.h>
#include <string.h>
#include <bastard.h>
#include <extension.h>


struct EXT__LANG *settings;

void ext_lang_init(void *param)
{
	settings = (struct EXT__LANG *) param;

	/* set Language-Specific information */
	if (!param)
		return;


	/* fill function pointers */
	return;
}


/* sprint a prototype for a given function */
int sprint_proto(char *buf, int len, int func_id)
{
	/* sprint $ret-type $name( */
	/* for i in func_params strncat (i) */
	/* sprint );\n */
	return (0);
}

/* sprint an entire function [usig fin_code] in HLL */
int sprint_func(char *buf, int len, int func_id)
{
	/* sprint proto */
	/* remove las char (;) */
	/* sprint {\n */
	/* for i in func_locals strncat \t$i\n */
	/* for i in fin_code strncat $i\n */
	/* sprint \n}\n */
	return (0);
}
/* generate the final high-level code for a function */
int gen_final(int func_id)
{
	/* for i in int_code do something magic.... */
	return (1);
}
/* generate a high-level language file for target */
int gen_file(FILE *f)
{
	/* do data types */
	/* for i in functions sprint_func */
	/* remainder */
	return (1);
}
